pybedtools.contrib.plotting.TrackCollection
===========================================

.. currentmodule:: pybedtools.contrib.plotting

.. autoclass:: TrackCollection

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TrackCollection.__init__
      ~TrackCollection.plot
   
   

   
   
   